import pytest

from sqlalchemy_api_handler.utils import nesting_datum_from


class UtilsTest:
    def test_nesting_datum(self, app):
        # Given
        datum = {
                  'offer.name': 'foo',
                  'offer.offerTags.0.tag.label': 'cir',
                  'offer.offerTags.0.tag.__SEARCH_BY__': 'label',
                  'offer.offerTags.1.tag.label': 'dor',
                  'offer.type': 'bar',
                  'price': 2
                }

        # When
        nesting_datum = nesting_datum_from(datum)

        # Then
        assert nesting_datum == {
            'offer': {
                'name': 'foo',
                'offerTags': [
                    {
                        'tag': {
                            'label': 'cir',
                            '__SEARCH_BY__': 'label'

                        }
                    },
                    {
                        'tag': {
                            'label': 'dor',

                        }
                    }
                ],
                'type': 'bar'
            },
            'price': 2,
        }



import pytest
from sqlalchemy_api_handler import ApiHandler
from sqlalchemy_api_handler.mixins import TaskState
from sqlalchemy_api_handler.serialization import as_dict

from tests.conftest import with_delete
from api.models.task import Task
from api.tasks.hello import print_text


class TaskerTest:
    @with_delete
    def test_create_eager_task(self, app):
        # Given
        text = 'Karl !'

        # When
        print_text.apply(args=(text,)).get()

        # Then
        task = Task.query.first()
        assert task.isEager == True
        assert task.name == 'api.tasks.hello.print_text'
        assert task.state == TaskState.SUCCEED
        assert task.result == { 'text': text }
